==> hns2_2.19.5.orig.tar.gz: hns-2.19.5/public_html/diary/lib/HNS/PIM/Link.pm <==
package HNS::PIM::Link;
# $Id: Link.pm,v 1.2 2001/04/14 23:32:07 kenji Exp $
################################################################
########
#diary/link
#ͥ URL ڡ̾
#ȵҤ롣
#ˤTodoȻ褦ˤ롣
#Ϥ
#<ul>
#<li><a href="URL">ڡ̾</a>
#<li><a href="http://www.yahoo.co.jp/">yahoo!JAPAN</a>
#
#</ul>
################################################################
=head1 NAME

HNS::PIM::Link - Link

=head1 SYNOPSIS

 my $link = new HNS::PIM::Link(filename=>'diary/link');
 $link->Read;
 print $link->AsHTML;


=cut

################################################################
use strict;
use ObjectTemplate;
use CodeConv;
@HNS::PIM::Link::ISA = qw(ObjectTemplate);

use HNS::System;
use HNS::Template;
use HNS::Diary::Template;

attributes qw(contents);

use vars qw($MaxNum $ContentTemplate $BeginTemplate $EndTemplate);
use vars qw(%ContentTemplate %BeginTemplate %EndTemplate);

#
#$MaxNum = 8:
$MaxNum = 8;

# template
#$ContentTemplate = "<li><strong>%priority</strong> %content</li>\n";
$ContentTemplate = "<li><a href=\"%e_url\">%content</a></li>\n";
$BeginTemplate = "<ul>";
$EndTemplate = "</ul>";

sub initialize($)
{
    my $self = shift;
    $self->contents([]);
}
################################################################

=head2 $t->Read;

ǡեɤ߹

=cut

sub Read ($)
{
    my $self = shift;
    my $filename = "$HNS::System::DiaryDir/link";
    open(F, $filename) || return;
    while (<F>){
#JISк⡣
	next if /^$/;
	CodeConv::toeuc(*_);
#Ƭ˿ʾ  ʤ󤫤ʸ 
#	/^(\d+)\s(.*)$/;
#	/^(\d+)\s(.*)\s(.*)$/;
	/^(\d+)\s(\S+)\s(.*)$/;
#	@{$self->contents} = split('/\s/', $self->contents);
	push(@{$self->contents},
	     {priority=>sprintf("%02d",$1), e_url=>$2, content=>$3});
#	     {priority=>sprintf("%02d",$1), content=>$2});
    }
    close F;
}

=head2 $t->AsHTML;

HTMLѴ֤

=cut

sub AsHTML ($)
{
    my $self = shift;
    my $templ = new HNS::Template;
    my $html .= SelectTemplate($BeginTemplate, %BeginTemplate);
    my $cnt;    

    for (sort {$b->{priority} <=> $a->{priority}} @{$self->contents}){
	last if ++$cnt > $MaxNum;
	$html .= $templ->Expand(SelectTemplate($ContentTemplate,
					       %ContentTemplate),
				{priority=>$_->{priority},
				 e_url=>$_->{e_url},
				 content=>$_->{content}});
    }
    $html .= SelectTemplate($EndTemplate, %EndTemplate);
}
	
1;

==> hns-2.19.9.tar.gz: hns-2.19.9/public_html/diary/lib/HNS/PIM/Link.pm <==
package HNS::PIM::Link;
# $Id: Link.pm,v 1.3 2003/05/28 04:52:55 togawa Exp $
################################################################
########
#diary/link
#ͥ URL ڡ̾
#ȵҤ롣
#ˤTodoȻ褦ˤ롣
#Ϥ
#<ul>
#<li><a href="URL">ڡ̾</a>
#<li><a href="http://www.yahoo.co.jp/">yahoo!JAPAN</a>
#
#</ul>
################################################################
=head1 NAME

HNS::PIM::Link - Link

=head1 SYNOPSIS

 my $link = new HNS::PIM::Link(filename=>'diary/link');
 $link->Read;
 print $link->AsHTML;


=cut

################################################################
use strict;
use ObjectTemplate;
use CodeConv;
@HNS::PIM::Link::ISA = qw(ObjectTemplate);

use HNS::System;
use HNS::Template;
use HNS::Diary::Template;

attributes qw(contents);

use vars qw($MaxNum $ContentTemplate $BeginTemplate $EndTemplate);
use vars qw(%ContentTemplate %BeginTemplate %EndTemplate);

#
#$MaxNum = 8:
$MaxNum = 8;

# template
#$ContentTemplate = "<li><strong>%priority</strong> %content</li>\n";
$ContentTemplate = "<li><a href=\"%e_url\">%content</a></li>\n";
$BeginTemplate = "<ul>";
$EndTemplate = "</ul>";

sub initialize($)
{
    my $self = shift;
    $self->contents([]);
}
################################################################

=head2 $t->Read;

ǡեɤ߹

=cut

sub Read ($)
{
    my $self = shift;
    my $filename = "$HNS::System::DiaryDir/link";
    open(F, $filename) || return;
    while (<F>){
#JISк⡣
	next if /^$/;
	CodeConv::toeuc(\$_);
#Ƭ˿ʾ  ʤ󤫤ʸ 
#	/^(\d+)\s(.*)$/;
#	/^(\d+)\s(.*)\s(.*)$/;
	/^(\d+)\s(\S+)\s(.*)$/;
#	@{$self->contents} = split('/\s/', $self->contents);
	push(@{$self->contents},
	     {priority=>sprintf("%02d",$1), e_url=>$2, content=>$3});
#	     {priority=>sprintf("%02d",$1), content=>$2});
    }
    close F;
}

=head2 $t->AsHTML;

HTMLѴ֤

=cut

sub AsHTML ($)
{
    my $self = shift;
    my $templ = new HNS::Template;
    my $html .= SelectTemplate($BeginTemplate, %BeginTemplate);
    my $cnt;    

    for (sort {$b->{priority} <=> $a->{priority}} @{$self->contents}){
	last if ++$cnt > $MaxNum;
	$html .= $templ->Expand(SelectTemplate($ContentTemplate,
					       %ContentTemplate),
				{priority=>$_->{priority},
				 e_url=>$_->{e_url},
				 content=>$_->{content}});
    }
    $html .= SelectTemplate($EndTemplate, %EndTemplate);
}
	
1;
